@@ -1,4 +1,3 @@
-from typing import Dict, List
 from pollination_dsl.dag import Inputs, DAG, task, Outputs
 from dataclasses import dataclass
 from pollination.honeybee_radiance.sky import GenSkyWithCertainIllum
@@ -28,6 +27,11 @@ class DaylightFactorEntryPoint(DAG):
         default='-ab 2 -aa 0.1 -ad 2048 -ar 64'
     )
 
+    sensor_grid = Inputs.str(
+        description='A grid name or a pattern to filter the sensor grids. By default '
+        'all the grids in HBJSON model will be exported.', default='*'
+    )
+
     model = Inputs.file(
         description='A Honeybee model in HBJSON file format.',
         extensions=['json', 'hbjson'],
@@ -35,13 +39,16 @@ class DaylightFactorEntryPoint(DAG):
     )
 
     @task(template=GenSkyWithCertainIllum)
-    def generate_sky(self) -> List[Dict]:
+    def generate_sky(self):
         return [
-            {'from': GenSkyWithCertainIllum()._outputs.sky, 'to': 'resources/100000_lux.sky'}
-            ]
+            {
+                'from': GenSkyWithCertainIllum()._outputs.sky,
+                'to': 'resources/100000_lux.sky'
+            }
+        ]
 
     @task(template=CreateRadianceFolder)
-    def create_rad_folder(self, input_model=model) -> List[Dict]:
+    def create_rad_folder(self, input_model=model, sensor_grid=sensor_grid):
         """Translate the input model to a radiance folder."""
         return [
             {'from': CreateRadianceFolder()._outputs.model_folder, 'to': 'model'},
@@ -75,14 +82,14 @@ class DaylightFactorEntryPoint(DAG):
         needs=[create_rad_folder, create_octree],
         loop=create_rad_folder._outputs.sensor_grids,
         sub_folder='initial_results/{{item.name}}',  # create a subfolder for each grid
-        sub_paths={'sensor_grid': 'grid/{{item.name}}.pts'}  # sub_path for sensor_grid arg
+        sub_paths={'sensor_grid': 'grid/{{item.full_id}}.pts'}  # sub_path for sensor_grid arg
     )
     def daylight_factor_ray_tracing(
         self,
         sensor_count=sensor_count,
         radiance_parameters=radiance_parameters,
         octree_file=create_octree._outputs.scene_file,
-        grid_name='{{item.name}}',
+        grid_name='{{item.full_id}}',
         sensor_grid=create_rad_folder._outputs.model_folder
     ):
         # this task doesn't return a file for each loop.
